pub struct SpanName;Expand description
Central registry of all tracing span names used in lmn.
Use the associated constants directly to get the right span name in a given context.
Implementations
Sourceimpl SpanName
impl SpanName
Sourcepub const TEMPLATE_PARSE: &'static str = "lmn.template.parse"
pub const TEMPLATE_PARSE: &'static str = "lmn.template.parse"
Span covering the full parse + validation of a request template file.
Sourcepub const TEMPLATE_RENDER: &'static str = "lmn.template.render"
pub const TEMPLATE_RENDER: &'static str = "lmn.template.render"
Span covering pre-generation of all request bodies from a template.
Sourcepub const TEMPLATE_VALIDATE_PLACEHOLDERS: &'static str = "lmn.template.validate_placeholders"
pub const TEMPLATE_VALIDATE_PLACEHOLDERS: &'static str = "lmn.template.validate_placeholders"
Span covering placeholder validation during template parsing.
Sourcepub const TEMPLATE_CHECK_CIRCULAR_REFS: &'static str = "lmn.template.check_circular_refs"
pub const TEMPLATE_CHECK_CIRCULAR_REFS: &'static str = "lmn.template.check_circular_refs"
Span covering circular reference detection during template parsing.
Sourcepub const RESPONSE_TEMPLATE_PARSE: &'static str = "lmn.response_template.parse"
pub const RESPONSE_TEMPLATE_PARSE: &'static str = "lmn.response_template.parse"
Span covering the full parse + validation of a response template file.