pub struct StepExec {
pub step_name: Arc<str>,
pub request_config: Arc<RequestConfig>,
pub plain_headers: Arc<Vec<(String, String)>>,
pub request_template: Option<Arc<Template>>,
pub response_template: Option<Arc<Vec<TrackedField>>>,
pub captures: Vec<CaptureDefinition>,
pub inline_body: Option<Arc<str>>,
pub has_capture_headers: bool,
}Expand description
All execution-ready data for a single step within a scenario.
Fields
step_name: Arc<str>request_config: Arc<RequestConfig>plain_headers: Arc<Vec<(String, String)>>Pre-converted header pairs — avoids per-request allocation.
request_template: Option<Arc<Template>>response_template: Option<Arc<Vec<TrackedField>>>Tracked fields parsed from the response template, if present.
captures: Vec<CaptureDefinition>Capture definitions to extract from the response body.
inline_body: Option<Arc<str>>Inline request body (mutually exclusive with request_template).
has_capture_headers: boolTrue if any header value contains {{capture. references.